%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Demo of Lagrange multipliers for PCA
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Create a 2D data set
N = 20;

X = randn(N,2);

V = [ 1.0 -0.6
     -1.0 -0.1 ];
  
X = X*V;

% Center it
mu = mean(X);
X = X - repmat(mu, N, 1);

% Do PCA
[U,S,W] = svd(X);

% Create the figure
figure(1);
clf();
hold on;

scatter(X(:,1), X(:,2), '.', 'k');

norm2 = @(X, varargin) sqrt(sum(X.^2, varargin{:}));

% Plot contours of the objective function
step = .01;
lim = 3;
[w1, w2] = meshgrid(-lim:step:lim, -lim:step:lim);
J = norm2(X*[w1(:) w2(:)]');
J = reshape(J, size(w1));

lambda = diag(S);
step = (lambda(1) - lambda(2))/3;

levels = (lambda(2)-2*step):step:(lambda(1)+2*step);

contour(w1, w2, J, levels, 'k');
contour(w1, w2, J, lambda(1), 'b', 'linewidth', 2);
contour(w1, w2, J, lambda(2), 'b', 'linewidth', 2);

% Plot the constraint
t = 0:.01:2*pi;
plot(cos(t), sin(t), 'r', 'linewidth', 2);

% Plot the extrema
scatter([W(1,:), -W(1,:)], [W(2,:), -W(2,:)], 500,'k', '.', 'linewidth', 2);

axis square;
print -depsc pca_lagrange.eps

