
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Demo: PCA map three dimensions to two
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Generate the data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

rng('default');
rng(2);

N = 200;

X = randn(N,3);  % 100 points from standard normal

W = [ 1.0 -0.5  0.3
      1.0  0.5 -0.2
      1.0 -0.5 -0.3 ];

X = X*W;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Do PCA
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[mu, W, lambda] = pca(X, 3);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot the results
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

figure(1);
clf();
colormap(jet);

SZ = 40;
marker = '.';
lw = 1;
C = X*W(:,1);
lim = [-6 6];

subplot(1,3,1);
scatter3(X(:,1), X(:,2), X(:,3), SZ, marker, 'linewidth', lw);
xlim(lim);
ylim(lim);
zlim(lim);


subplot(1,3,2);
scatter3(X(:,1), X(:,2), X(:,3), SZ, C, marker, 'linewidth', lw);
xlim(lim);
ylim(lim);
zlim(lim);

hold on;

%Plot the directions
for j=1:3
    x = 2.5*(-lambda(j):.01:lambda(j))/sqrt(N)';
    plot3(W(1,j)*x, W(2,j)*x, W(3,j)*x, 'k', 'linewidth', 2);
end

%lambda = lambda.*sgn;

subplot(1,3,3);
colormap(jet);
scatter(X*W(:,1), X*W(:,2), SZ, C, marker, 'linewidth', lw);

xlim(lim);
ylim(lim);


