function pca_digit_demo( X, k )

    if nargin < 2
        k = 4;
    end

    [mu, W, ~, X] = pca(X, k);

    N = size(X,1);
   

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Show mean and top k principle components
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    figure(1);
    clf();
    colormap(gray);
    
    subplot(1, k+1, 1);
    imagesc(reshape(mu, 20, 20));

    for i=1:k
       subplot(1, k+1, i+1);
       imagesc(reshape(W(:,i), 20, 20));    
    end


    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Display 100 digits plotted by their projection onto principle components
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    U = X*W;
    
    w = 2*max(abs(U(1:2*N)));
    n = 20;
    pixel_sz = w/600;
    x_pixel_inds = ((1:n)-n/2)'*pixel_sz;
    y_pixel_inds = ((n:-1:1)-n/2)'*pixel_sz;

    figure(2);
    clf();
    hold on;
        
    for j=[1 2]
                
        for i=1:200
            
            I = reshape(X(i,:)+mu, n, n);
            
            xcoord = U(i,1);
            ycoord = U(i,2);
            
            imagesc(xcoord + x_pixel_inds, ycoord + y_pixel_inds, I);
        end
        colormap(gray);
    end
end

